@@ -6,19 +6,8 @@ import ast
 import os.path
 from typing import Any, MutableMapping, Optional
 
-try:
-    import tomllib
-except ModuleNotFoundError:  # pragma: no cover
-    import tomli as tomllib  # type: ignore
-except ImportError:  # pragma: no cover
-    tomllib = None  # type: ignore
-
-try:
-    import yaml
-except ImportError:  # pragma: no cover
-    yaml = None  # type: ignore
-
 from .exceptions import ScrivException
+from .optional import tomllib, yaml
 
 
 def find_literal(file_name: str, literal_name: str) -> Optional[str]:
@@ -89,6 +78,11 @@ class PythonLiteralFinder(ast.NodeVisitor):
                 if target.id == self.name:
                     self.check_value(node.value)
 
+    def visit_AnnAssign(self, node) -> None:  # noqa: D102 (inherited docstring)
+        if isinstance(node.target, ast.Name):
+            if node.target.id == self.name:
+                self.check_value(node.value)
+
     def check_value(self, value):
         """
         Check a value node to see if it's a string constant.
