@@ -5,11 +5,14 @@ import pytest
 import scriv.literals
 from scriv.exceptions import ScrivException
 from scriv.literals import find_literal
+from scriv.optional import tomllib, yaml
 
 PYTHON_CODE = """\
 # A string we should get.
 version = "1.2.3"
 
+typed_version: Final[str] = "2.3.4"
+
 # Numbers don't count.
 how_many = 123
 
@@ -37,6 +40,7 @@ def foo():
     "name, value",
     [
         ("version", "1.2.3"),
+        ("typed_version", "2.3.4"),
         ("also", "xyzzy"),
         ("but", "hello there"),
         ("somewhere_else", "this would be an odd place to get the string"),
@@ -81,6 +85,7 @@ bad_type = nan
 """
 
 
+@pytest.mark.skipif(tomllib is None, reason="No TOML support installed")
 @pytest.mark.parametrize(
     "name, value",
     [
@@ -128,6 +133,7 @@ myproduct:
 """
 
 
+@pytest.mark.skipif(yaml is None, reason="No YAML support installed")
 @pytest.mark.parametrize(
     "name, value",
     [
